summaryrefslogtreecommitdiff
path: root/gen.sh
diff options
context:
space:
mode:
authorknolax <1339802534.kk@gmail.com>2017-11-14 09:35:43 -0500
committerknolax <1339802534.kk@gmail.com>2017-11-14 09:35:43 -0500
commit8795d52462f0c8084589748851a513c5ceb5ba55 (patch)
tree75beebe2175863c5fa236f6f1511cf67e8d487bb /gen.sh
parente6116f2dde5c3b38b4cab55899e3e23c55d8ede7 (diff)
changed home.html to index.html
Diffstat (limited to 'gen.sh')
-rwxr-xr-xgen.sh8
1 files changed, 4 insertions, 4 deletions
diff --git a/gen.sh b/gen.sh
index a870ab3..dda13c6 100755
--- a/gen.sh
+++ b/gen.sh
@@ -1,7 +1,7 @@
-pages=$(ls -S -t cont/| grep html | grep -v home.html) #lists the actual content
+pages=$(ls -S -t cont/| grep html | grep -v index.html) #lists the actual content
#-S -t so that the files are roughly in time order
-#home is excluded and appended at the end to make sure it gets processed last
-pages="$pages home.html"
+#index is excluded and appended at the end to make sure it gets processed last
+pages="$pages index.html"
#clears the index
rm index
for page in $pages; do
@@ -23,7 +23,7 @@ for page in $pages; do
cat $page.tmp | sed '/\\\[SETDATE\]/bx; /\[SETDATE\].*/d;:x s/\\\[SETDATE\]/\[SETDATE\]/' >> $page
#adds the index if its the homepage
- if [ "$page" == "home.html" ]; then
+ if [ "$page" == "index.html" ]; then
cat index >> $page
rm index
fi